@@ -15,8 +15,7 @@ from matplotlib import pyplot
 
 
 from Bio._py3k import map, range, zip
-iteritems = (dict.iteritems if sys.version < 3
-             else dict.items)
+iteritems = (dict.iteritems if sys.version_info[0] < 3 else dict.items)
 
 from . import (core, target, antitarget, coverage, fix, metrics, reference,
                reports, export, importers, segmentation,
@@ -72,7 +71,7 @@ def _cmd_batch(args):
         if not args.targets:
             raise ValueError("Argument -t/--target is required.")
         # Build a copy number reference; update (anti)targets upon request
-        args.reference, args.targets, args.antitargets =  batch_make_reference(
+        args.reference, args.targets, args.antitargets = batch_make_reference(
             args.normal, args.targets, args.antitargets, args.male_normal,
             args.fasta, args.annotate, args.short_names, args.split,
             args.target_avg_size, args.access, args.antitarget_avg_size,
@@ -88,18 +87,19 @@ def _cmd_batch(args):
         core.write_tsv(args.targets, target_coords)
         core.write_tsv(args.antitargets, antitarget_coords)
 
-    echo("Running", len(args.bam_files), "samples in",
-         (("%d processes" % args.processes)
-          if args.processes > 1 else "serial"))
+    if args.bam_files:
+        echo("Running", len(args.bam_files), "samples in",
+             (("%d processes" % args.processes)
+              if args.processes > 1 else "serial"))
 
-    pool = pick_pool(args.processes)
-    for bam in args.bam_files:
-        pool.apply_async(batch_run_sample,
-                         (bam, args.targets, args.antitargets, args.reference,
-                          args.output_dir, args.male_normal, args.scatter,
-                          args.diagram, args.rlibpath))
-    pool.close()
-    pool.join()
+        pool = pick_pool(args.processes)
+        for bam in args.bam_files:
+            pool.apply_async(batch_run_sample,
+                             (bam, args.targets, args.antitargets, args.reference,
+                              args.output_dir, args.male_normal, args.scatter,
+                              args.diagram, args.rlibpath))
+        pool.close()
+        pool.join()
 
 
 def batch_make_reference(normal_bams, target_bed, antitarget_bed, male_normal,
@@ -123,7 +123,7 @@ def batch_make_reference(normal_bams, target_bed, antitarget_bed, male_normal,
         target_bed = new_target_fname
 
     if not antitarget_bed:
-        # Build antitargets from the given targets
+        # Build antitarget BED from the given targets
         anti_kwargs = {}
         if access:
             anti_kwargs['access_bed'] = access
@@ -217,7 +217,7 @@ def batch_run_sample(bam_fname, target_bed, antitarget_bed, ref_fname,
 
 
 P_batch = AP_subparsers.add_parser('batch', help=_cmd_batch.__doc__)
-P_batch.add_argument('bam_files', nargs='+',
+P_batch.add_argument('bam_files', nargs='*',
         help="Mapped sequence reads (.bam)")
 P_batch.add_argument('-y', '--male-normal', action='store_true',
         help="""Use or assume a male reference (i.e. female samples will have +1
@@ -411,16 +411,9 @@ def _cmd_coverage(args):
 
 def do_coverage(bed_fname, bam_fname, by_count=False):
     """Calculate coverage in the given regions from BAM read depths."""
-    try:
-        is_sorted = ngfrills.ensure_bam_sorted(bam_fname)
-    except RuntimeError:
-        # pysam wasn't available, probably
-        pass
-    else:
-        if not is_sorted:
-            raise RuntimeError("BAM file %s must be sorted by coordinates"
-                               % bam_fname)
-
+    if not ngfrills.ensure_bam_sorted(bam_fname):
+        raise RuntimeError("BAM file %s must be sorted by coordinates"
+                            % bam_fname)
     ngfrills.ensure_bam_index(bam_fname)
     # ENH: count importers.TOO_MANY_NO_COVERAGE & warn
     if by_count:
@@ -462,7 +455,7 @@ def _cmd_reference(args):
                                 if f.endswith('targetcoverage.cnn'))
             else:
                 filenames.append(path)
-        targets = [f for f in filenames if not 'antitarget' in f]
+        targets = [f for f in filenames if 'antitarget' not in f]
         antitargets = [f for f in filenames if 'antitarget' in f]
         echo("Number of target and antitarget files: %d, %d"
             % (len(targets), len(antitargets)))
@@ -488,7 +481,7 @@ def do_reference(target_fnames, antitarget_fnames, fa_fname=None,
     ref_probes.extend(reference.combine_probes(antitarget_fnames,
                                                bool(fa_fname), male_normal))
     ref_probes.sort()
-    ref_probes.center_all()
+    ref_probes.center_all(mode=True)
     # Calculate GC and RepeatMasker content for each probe's genomic region
     if fa_fname:
         gc, rmask = reference.get_fasta_stats(ref_probes, fa_fname)
@@ -557,33 +550,33 @@ def _cmd_fix(args):
     biases and re-center.
     """
     # Verify that target and antitarget are from the same sample
-    tgt_pset = CNA.read(args.target)
-    anti_pset = CNA.read(args.antitarget)
-    if tgt_pset.sample_id != anti_pset.sample_id:
+    tgt_raw = CNA.read(args.target)
+    anti_raw = CNA.read(args.antitarget)
+    if tgt_raw.sample_id != anti_raw.sample_id:
         raise ValueError("Sample IDs do not match:"
                          "'%s' (target) vs. '%s' (antitarget)"
-                         % (tgt_pset.sample_id, anti_pset.sample_id))
-    target_table = do_fix(tgt_pset, anti_pset, CNA.read(args.reference),
+                         % (tgt_raw.sample_id, anti_raw.sample_id))
+    target_table = do_fix(tgt_raw, anti_raw, CNA.read(args.reference),
                           args.do_gc, args.do_edge, args.do_rmask)
-    target_table.write(args.output or tgt_pset.sample_id + '.cnr')
+    target_table.write(args.output or tgt_raw.sample_id + '.cnr')
 
 
-def do_fix(target_pset, antitarget_pset, reference_pset,
+def do_fix(target_raw, antitarget_raw, reference,
            do_gc=True, do_edge=True, do_rmask=True):
     """Combine target and antitarget coverages and correct for biases."""
     # Load, recenter and GC-correct target & antitarget probes separately
-    echo("Processing target:", target_pset.sample_id)
-    target_table = fix.load_adjust_coverages(target_pset, reference_pset,
-                                             do_gc, do_edge, False)
-    echo("Processing antitarget:", antitarget_pset.sample_id)
-    atarget_table = fix.load_adjust_coverages(antitarget_pset, reference_pset,
-                                              do_gc, False, do_rmask)
-
+    echo("Processing target:", target_raw.sample_id)
+    cnarr = fix.load_adjust_coverages(target_raw, reference,
+                                      do_gc, do_edge, False)
+    echo("Processing antitarget:", antitarget_raw.sample_id)
+    anti_cnarr = fix.load_adjust_coverages(antitarget_raw, reference,
+                                           do_gc, False, do_rmask)
     # Merge target and antitarget & sort probes by chromosomal location
-    target_table.extend(atarget_table)
-    target_table.sort()
+    cnarr.extend(anti_cnarr)
+    cnarr.sort()
+    cnarr.center_all(mode=True)
     # Determine weights for each bin (used in segmentation)
-    return fix.apply_weights(target_table, reference_pset)
+    return fix.apply_weights(cnarr, reference)
 
 
 P_fix = AP_subparsers.add_parser('fix', help=_cmd_fix.__doc__)
