@@ -5,7 +5,7 @@ import os.path
 import time
 from itertools import groupby
 
-from Bio._py3k import map, range, zip
+from Bio._py3k import map, zip
 import pysam
 
 from . import ngfrills
@@ -69,7 +69,8 @@ def region_depth_count(bamfile, chrom, start, end):
                                           start=start, end=end))
     # Scale read counts to region length
     # Depth := #Bases / Span
-    depth = READ_LEN * count / (end - start)
+    depth = (READ_LEN * count / (end - start)
+             if end > start else 0)
     return count, depth
 
 
@@ -113,9 +114,14 @@ def bedcov(bed_fname, bam_fname):
     i.e. mean pileup depth across each region.
     """
     # Count bases in each region; exclude 0-MAPQ reads
-    lines = pysam.bedcov(bed_fname, bam_fname, '-Q', '1')
+    try:
+        lines = pysam.bedcov(bed_fname, bam_fname, '-Q', '1')
+    except pysam.SamtoolsError, exc:
+        raise ValueError("Failed processing %r coverages in %r regions. PySAM error: %s"
+                         % (bam_fname, bed_fname, exc))
     if not lines:
-        raise ValueError("BED file sequence IDs don't match any in the BAM: %s %s" % (bed_fname, bam_fname))
+        raise ValueError("BED file %r sequence IDs don't match any in BAM file %r"
+                         % (bed_fname, bam_fname))
     # Return an iterable...
     for line in lines:
         try:
@@ -124,9 +130,13 @@ def bedcov(bed_fname, bam_fname):
             raise RuntimeError("Bad line from bedcov:\n" + line)
         start, end, basecount = map(int, (start_s, end_s, basecount_s.strip()))
         span = end - start
-        # Algebra from above
-        count = basecount / READ_LEN
-        mean_depth = basecount / span
+        if span > 0:
+            # Algebra from above
+            count = basecount / READ_LEN
+            mean_depth = basecount / span
+        else:
+            # User-supplied bins might be oddly constructed
+            count = mean_depth = 0
         yield chrom, start, end, name, count, mean_depth
 
 
